#
# spec file for package libGLC
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libGLC
Version:        0.7.2
Release:        4.3
Summary:        Free OpenGL Character Renderer
License:        LGPL-2.1-or-later
URL:            http://quesoglc.sf.net/
Source:         http://sourceforge.net/projects/quesoglc/files/%{version}/quesoglc-%{version}.tar.bz2
Patch1:         quesoglc-typepun.diff
BuildRequires:  Mesa-devel
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glut)
BuildRequires:  pkgconfig(ice)

%description
QuesoGLC is a free (as in free speech) implementation of the OpenGL
Character Renderer (GLC). QuesoGLC is based on the FreeType library,
provides Unicode support and is designed to be easily ported to any
platform that supports both FreeType and the OpenGL API.

%package -n libGLC0
Summary:        Free OpenGL Character Renderer

%description -n libGLC0
QuesoGLC is a free (as in free speech) implementation of the OpenGL
Character Renderer (GLC). QuesoGLC is based on the FreeType library,
provides Unicode support and is designed to be easily ported to any
platform that supports both FreeType and the OpenGL API.

%package devel
Summary:        QuesoGLC Development Files
Requires:       Mesa-devel
Requires:       libGLC0 = %{version}
Requires:       pkgconfig(expat)
Requires:       pkgconfig(fontconfig)
Requires:       pkgconfig(freetype2)
Requires:       pkgconfig(zlib)

%description devel
This package contains all necessary include files and libraries needed
to develop applications using QuesoGLC.

%prep
%autosetup -n quesoglc-%{version} -p1

%build
export CFLAGS="%{optflags} -Wno-incompatible-pointer-types"
%configure \
  --disable-static
%make_build

%ldconfig_scriptlets -n libGLC0

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%files -n libGLC0
%license COPYING
%doc AUTHORS ChangeLog README THANKS
%{_libdir}/libGLC.so.*

%files devel
%{_includedir}/*
%{_libdir}/libGLC.so
%{_libdir}/pkgconfig/quesoglc.pc

%changelog
* Tue Dec 10 2024 Martin Pluskal <mpluskal@suse.com>
- Fix building on Tumbleweed
- Minor spec file modernisation
* Wed Apr  6 2022 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
* Fri Jun 19 2015 mpluskal@suse.com
- Use url for source
- Do not ship .la file
- Update dependencies to avoid building bundled libraries
- Enable tests during build
* Tue Jun 25 2013 joop.boonen@opensuse.org
- Added missing BuildRequires: pkg-config
- Changed Group: Development/Libraries/C and C++
* Sun Feb 19 2012 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Fix deref-of-typepun-ptr error in source code
* Thu Oct  1 2009 joop.boonen@opensuse.org
- Build with -fno-strict-aliasing
- Don't build the static library anymore
* Wed Sep 30 2009 joop.boonen@opensuse.org
- A separate rpm file will be created for the static libraries
* Sun Sep 27 2009 joop.boonen@opensuse.org
- build version 0.7.2
  + Fixed bug #2019450 (added a workaround for open source drivers of the Intel chipsets : a bug in the drivers prevent a character to be displayed).
  + Fixed a bug which caused some memory leaks when memory allocation failed during the update of the masters.
  + Updated the demo in the examples: extrusion and ligthing have been added.
  + Fixed glcGetFontMap() and glcGetMasterMap() so that their return is not null when a character is mapped in the font/master but its Unicode name is not stored in QuesoGLC database.
  + Character codes out of range are now rejected when GLC_UCS1 or GLC_UCS2 are enabled. GLC_PARAMETER_ERROR is then raised.
  + Fixed a bug that crashed QuesoGLC when trying to call glcGetFontMap() with a character not mapped in the font.
  + Fixed a bug which caused the measurement caches not to be updated when GLC_RESOLUTION was changed by the users.
  + Fixed a memory leak in the management of the texture atlas: when a font was deleted, the memory allocated to this font in the atlas was definitely lost instead of being given back to the texture allocator.
  + Fixed a bug which did not include trailing spaces in the calculation of bounding boxes.
  + Fixed a bug which caused artifacts when rendering glyphes that extend beyond the EM square.
  + Fixed a bug which prevented letters l and i to be displayed at small scales when GLC_HINTING_QSO and GLC_TEXTURE were enabled.
  + Side effect of the above bug fix : the antialiasing is improved for most characters since they are no longer located against the edges of the texture.
  + Fixed a bug in glcGenFontID() which could return the ID of an existing font.
  + Fixed a race condition in glcGenContext()
  + Function glcGetStringCharMetric() now returns metrics in global string coordinates (otherwise the kerning can not be measured)
  + Fixed bug #1987563 (Kerning does not work when GLC_GL_OBJECTS is enabled) Thanks to GenPFault for the bug report.
  + Fixed bug #2012579 (Mac OSX Leopard compiling bug) - Thanks to Michael Strobel and Tim Baumgartner for the bug report and the patch.
  + Negative values passed to glcResolution() now raise GLC_PARAMETER_ERROR
  + Fixed bug #1980982 (Checks for MinGW in the configure script are incomplete)
  + Feature request #1947346 : added files for pkg-config (thanks to Giel van Shijndel and Dennis Schridde for providing them)
  + Fixed bug #1947464 (Warnings are generated when compiling with gcc option -Wstrict-prototypes)
  + Fixed bug #1935557 (Fonts are not rendered correctly when the resolution is changed using glcResolution).
* Mon Jul 28 2008 prusnak@suse.cz
- created from home:wstephenson project (version 0.7.1)
